@@ -32,9 +32,9 @@ module Test
     #
     # @example Example Custom Assertion
     #
-    #   def deny(boolean, message = nil)
-    #     message = build_message message, '<?> is not false or nil.', boolean
-    #     assert_block message do
+    #   def deny(boolean, message=nil)
+    #     message = build_message(message, '<?> is not false or nil.', boolean)
+    #     assert_block(message) do
     #       not boolean
     #     end
     #   end
@@ -52,7 +52,11 @@ module Test
       def assert_block(message="assert_block failed.")
         _wrap_assertion do
           if (! yield)
-            raise AssertionFailedError.new(message.to_s)
+            options = {}
+            if message.respond_to?(:user_message)
+              options[:user_message] = message.user_message
+            end
+            raise AssertionFailedError.new(message.to_s, options)
           end
         end
       end
@@ -167,7 +171,7 @@ module Test
         end
       end
 
-      # Asserts that +object+ is false or nil.
+      # Asserts that `object` is false or nil.
       #
       # @note Just for minitest compatibility. :<
       #
@@ -209,7 +213,7 @@ module Test
       end
 
       ##
-      # Passes if +expected+ == +actual+.
+      # Passes if `expected` == `actual`.
       #
       # Note that the ordering of arguments is important, since a helpful
       # error message is generated when this one fails that tells you the
@@ -239,7 +243,7 @@ EOT
         begin
           assert_block(full_message) { expected == actual }
         rescue AssertionFailedError => failure
-          _set_failed_information(failure, expected, actual, message)
+          _set_failed_information(failure, expected, actual)
           raise failure # For JRuby. :<
         end
       end
@@ -275,8 +279,7 @@ EOT
                 assert_exception_helper.expected?(actual_exception)
             end
           rescue AssertionFailedError => failure
-            _set_failed_information(failure, expected, actual_exception,
-                                    message)
+            _set_failed_information(failure, expected, actual_exception)
             raise failure # For JRuby. :<
           end
         end
@@ -311,7 +314,7 @@ EOT
 
 
       ##
-      # Passes if +object+.instance_of?(+klass+). When +klass+ is
+      # Passes if `object`.instance_of?(`klass`). When `klass` is
       # an array of classes, it passes if any class
       # satisfies +object.instance_of?(class).
       #
@@ -319,7 +322,7 @@ EOT
       #   assert_instance_of(String, 'foo')            # -> pass
       #   assert_instance_of([Fixnum, NilClass], 100)  # -> pass
       #   assert_instance_of([Numeric, NilClass], 100) # -> fail
-      def assert_instance_of(klass, object, message="")
+      def assert_instance_of(klass, object, message=nil)
         _wrap_assertion do
           if klass.is_a?(Array)
             klasses = klass
@@ -345,8 +348,8 @@ EOT
       end
 
       ##
-      # Passes if +object+.instance_of?(+klass+) does not hold.
-      # When +klass+ is an array of classes, it passes if no class
+      # Passes if `object`.instance_of?(`klass`) does not hold.
+      # When `klass` is an array of classes, it passes if no class
       # satisfies +object.instance_of?(class).
       #
       # @example
@@ -355,7 +358,7 @@ EOT
       #   assert_not_instance_of([Numeric, NilClass], 100)   # -> fail
       #
       # @since 3.0.0
-      def assert_not_instance_of(klass, object, message="")
+      def assert_not_instance_of(klass, object, message=nil)
         _wrap_assertion do
           if klass.is_a?(Array)
             klasses = klass
@@ -386,11 +389,11 @@ EOT
       alias_method :refute_instance_of, :assert_not_instance_of
 
       ##
-      # Passes if +object+ is nil.
+      # Passes if `object` is nil.
       #
       # @example
       #   assert_nil [1, 2].uniq!
-      def assert_nil(object, message="")
+      def assert_nil(object, message=nil)
         full_message = build_message(message, <<EOT, object)
 <?> was expected to be nil.
 EOT
@@ -398,7 +401,7 @@ EOT
       end
 
       ##
-      # Passes if +object+.kind_of?(+klass+). When +klass+ is
+      # Passes if `object`.kind_of?(`klass`). When `klass` is
       # an array of classes or modules, it passes if any
       # class or module satisfies +object.kind_of?(class_or_module).
       #
@@ -406,7 +409,7 @@ EOT
       #   assert_kind_of(Object, 'foo')                # -> pass
       #   assert_kind_of([Fixnum, NilClass], 100)      # -> pass
       #   assert_kind_of([Fixnum, NilClass], "string") # -> fail
-      def assert_kind_of(klass, object, message="")
+      def assert_kind_of(klass, object, message=nil)
         _wrap_assertion do
           if klass.is_a?(Array)
             klasses = klass
@@ -434,8 +437,8 @@ EOT
       end
 
       ##
-      # Passes if +object+.kind_of?(+klass+) does not hold.
-      # When +klass+ is an array of classes or modules, it passes only if all
+      # Passes if `object`.kind_of?(`klass`) does not hold.
+      # When `klass` is an array of classes or modules, it passes only if all
       # classes (and modules) do not satisfy +object.kind_of?(class_or_module).
       #
       # @example
@@ -444,7 +447,7 @@ EOT
       #   assert_not_kind_of([Fixnum, NilClass], 100) # -> fail
       #
       # @since 3.0.0
-      def assert_not_kind_of(klass, object, message="")
+      def assert_not_kind_of(klass, object, message=nil)
         _wrap_assertion do
           if klass.is_a?(Array)
             klasses = klass
@@ -475,11 +478,11 @@ EOT
       alias_method :refute_kind_of, :assert_not_kind_of
 
       ##
-      # Passes if +object+ .respond_to? +method+
+      # Passes if `object` .respond_to? `method`
       #
       # @example
       #   assert_respond_to 'bugbear', :slice
-      def assert_respond_to(object, method, message="")
+      def assert_respond_to(object, method, message=nil)
         _wrap_assertion do
           full_message = build_message(message,
                                        "<?>.kind_of\\?(Symbol) or\n" +
@@ -497,12 +500,12 @@ EOT
       end
 
       ##
-      # Passes if +object+ does not .respond_to? +method+.
+      # Passes if `object` does not .respond_to? `method`.
       #
       # @example
       #   assert_not_respond_to('bugbear', :nonexistence) # -> pass
       #   assert_not_respond_to('bugbear', :size)         # -> fail
-      def assert_not_respond_to(object, method, message="")
+      def assert_not_respond_to(object, method, message=nil)
         _wrap_assertion do
           full_message = build_message(message,
                                        "<?>.kind_of\\?(Symbol) or\n" +
@@ -525,18 +528,13 @@ EOT
       alias_method :refute_respond_to, :assert_not_respond_to
 
       ##
-      # Passes if +pattern+ =~ +string+.
+      # Passes if `pattern` =~ `string`.
       #
       # @example
       #   assert_match(/\d+/, 'five, 6, seven')
-      def assert_match(pattern, string, message="")
+      def assert_match(pattern, string, message=nil)
         _wrap_assertion do
-          pattern = case(pattern)
-            when String
-              Regexp.new(Regexp.escape(pattern))
-            else
-              pattern
-          end
+          pattern = Regexp.new(Regexp.escape(pattern)) if pattern.is_a?(String)
           full_message = build_message(message,
                                        "<?> was expected to be =~\n<?>.",
                                        pattern, string)
@@ -545,13 +543,13 @@ EOT
       end
 
       ##
-      # Passes if +actual+ .equal? +expected+ (i.e. they are the same
+      # Passes if `actual` .equal? `expected` (i.e. they are the same
       # instance).
       #
       # @example
       #   o = Object.new
       #   assert_same o, o
-      def assert_same(expected, actual, message="")
+      def assert_same(expected, actual, message=nil)
         full_message = build_message(message, <<EOT, expected, expected.__id__, actual, actual.__id__)
 <?>
 with id <?> was expected to be equal\\? to
@@ -562,13 +560,13 @@ EOT
       end
 
       ##
-      # Compares the +object1+ with +object2+ using +operator+.
+      # Compares the `object1` with `object2` using `operator`.
       #
       # Passes if object1.__send__(operator, object2) is true.
       #
       # @example
       #   assert_operator 5, :>=, 4
-      def assert_operator(object1, operator, object2, message="")
+      def assert_operator(object1, operator, object2, message=nil)
         _wrap_assertion do
           full_message = build_message(nil, "<?>\ngiven as the operator for #assert_operator must be a Symbol or #respond_to\\?(:to_str).", operator)
           assert_block(full_message){operator.kind_of?(Symbol) || operator.respond_to?(:to_str)}
@@ -582,7 +580,7 @@ EOT
       end
 
       ##
-      # Compares the +object1+ with +object2+ using +operator+.
+      # Compares the `object1` with `object2` using `operator`.
       #
       # Passes if object1.__send__(operator, object2) is not true.
       #
@@ -591,7 +589,7 @@ EOT
       #   assert_not_operator(5, :>, 4) # => fail
       #
       # @since 3.0.0
-      def assert_not_operator(object1, operator, object2, message="")
+      def assert_not_operator(object1, operator, object2, message=nil)
         _wrap_assertion do
           full_message = build_message(nil, "<?>\ngiven as the operator for #assert_not_operator must be a Symbol or #respond_to\\?(:to_str).", operator)
           assert_block(full_message){operator.kind_of?(Symbol) || operator.respond_to?(:to_str)}
@@ -649,11 +647,11 @@ EOT
       end
 
       ##
-      # Passes if ! +actual+ .equal? +expected+
+      # Passes if ! `actual` .equal? `expected`
       #
       # @example
       #   assert_not_same Object.new, Object.new
-      def assert_not_same(expected, actual, message="")
+      def assert_not_same(expected, actual, message=nil)
         full_message = build_message(message, <<EOT, expected, expected.__id__, actual, actual.__id__)
 <?>
 with id <?> was expected to not be equal\\? to
@@ -669,11 +667,11 @@ EOT
       alias_method :refute_same, :assert_not_same
 
       ##
-      # Passes if +expected+ != +actual+
+      # Passes if `expected` != `actual`
       #
       # @example
       #   assert_not_equal 'some string', 5
-      def assert_not_equal(expected, actual, message="")
+      def assert_not_equal(expected, actual, message=nil)
         full_message = build_message(message,
                                      "<?> was expected to be != to\n<?>.",
                                      expected, actual)
@@ -686,11 +684,11 @@ EOT
       alias_method :refute_equal, :assert_not_equal
 
       ##
-      # Passes if ! +object+ .nil?
+      # Passes if ! `object` .nil?
       #
       # @example
       #   assert_not_nil '1 two 3'.sub!(/two/, '2')
-      def assert_not_nil(object, message="")
+      def assert_not_nil(object, message=nil)
         full_message = build_message(message,
                                      "<?> was expected to not be nil.",
                                      object)
@@ -703,20 +701,18 @@ EOT
       alias_method :refute_nil, :assert_not_nil
 
       ##
-      # Passes if +regexp+ !~ +string+
+      # Passes if `regexp` !~ `string`
       #
       # @example
       #   assert_not_match(/two/, 'one 2 three')   # -> pass
       #   assert_not_match(/three/, 'one 2 three') # -> fail
-      def assert_not_match(regexp, string, message="")
+      def assert_not_match(pattern, string, message=nil)
         _wrap_assertion do
-          assert_instance_of(Regexp, regexp,
-                             "<REGEXP> in assert_not_match(<REGEXP>, ...) " +
-                             "should be a Regexp.")
+          pattern = Regexp.new(Regexp.escape(pattern)) if pattern.is_a?(String)
           full_message = build_message(message,
                                        "<?> was expected to not match\n<?>.",
-                                       regexp, string)
-          assert_block(full_message) { regexp !~ string }
+                                       pattern, string)
+          assert_block(full_message) { pattern !~ string }
         end
       end
 
@@ -728,7 +724,7 @@ EOT
       ##
       # Deprecated. Use #assert_not_match instead.
       #
-      # Passes if +regexp+ !~ +string+
+      # Passes if `regexp` !~ `string`
       #
       # @example
       #   assert_no_match(/two/, 'one 2 three')   # -> pass
@@ -786,13 +782,13 @@ EOT
       end
 
       ##
-      # Passes if the block throws +expected_object+
+      # Passes if the block throws `expected_object`
       #
       # @example
       #   assert_throw(:done) do
       #     throw(:done)
       #   end
-      def assert_throw(expected_object, message="", &proc)
+      def assert_throw(expected_object, message=nil, &proc)
         _wrap_assertion do
           begin
             catch([]) {}
@@ -838,7 +834,7 @@ EOT
       #  assert_nothing_thrown do
       #    [1, 2].uniq
       #  end
-      def assert_nothing_thrown(message="", &proc)
+      def assert_nothing_thrown(message=nil, &proc)
         _wrap_assertion do
           assert(block_given?, "Should have passed a block to assert_nothing_thrown")
           begin
@@ -857,8 +853,8 @@ EOT
       end
 
       ##
-      # Passes if +expected_float+ and +actual_float+ are equal
-      # within +delta+ tolerance.
+      # Passes if `expected_float` and `actual_float` are equal
+      # within `delta` tolerance.
       #
       # @example
       #   assert_in_delta 0.05, (50000.0 / 10**6), 0.00001
@@ -878,8 +874,8 @@ EOT
       end
 
       ##
-      # Passes if +expected_float+ and +actual_float+ are
-      # not equal within +delta+ tolerance.
+      # Passes if `expected_float` and `actual_float` are
+      # not equal within `delta` tolerance.
       #
       # @example
       #   assert_not_in_delta(0.05, (50000.0 / 10**6), 0.00002) # -> pass
@@ -978,8 +974,8 @@ EOT
 
       public
       ##
-      # Passes if +expected_float+ and +actual_float+ are equal
-      # within +epsilon+ relative error of +expected_float+.
+      # Passes if `expected_float` and `actual_float` are equal
+      # within `epsilon` relative error of `expected_float`.
       #
       # @example
       #   assert_in_epsilon(10000.0, 9900.0, 0.1) # -> pass
@@ -1008,9 +1004,9 @@ EOT
       end
 
       ##
-      # Passes if +expected_float+ and +actual_float+ are
-      # not equal within +epsilon+ relative error of
-      # +expected_float+.
+      # Passes if `expected_float` and `actual_float` are
+      # not equal within `epsilon` relative error of
+      # `expected_float`.
       #
       # @example
       #   assert_not_in_epsilon(10000.0, 9900.0, 0.1) # -> fail
@@ -1118,7 +1114,7 @@ EOT
       ##
       # Passes if the method send returns a true value.
       #
-      # +send_array+ is composed of:
+      # `send_array` is composed of:
       # * A receiver
       # * A method
       # * Arguments to the method
@@ -1158,7 +1154,7 @@ EOT
       ##
       # Passes if the method send doesn't return a true value.
       #
-      # +send_array+ is composed of:
+      # `send_array` is composed of:
       # * A receiver
       # * A method
       # * Arguments to the method
@@ -1196,7 +1192,7 @@ EOT
       end
 
       ##
-      # Passes if +actual+ is a boolean value.
+      # Passes if `actual` is a boolean value.
       #
       # @example
       #   assert_boolean(true) # -> pass
@@ -1212,7 +1208,7 @@ EOT
       end
 
       ##
-      # Passes if +actual+ is true.
+      # Passes if `actual` is true.
       #
       # @example
       #   assert_true(true)  # -> pass
@@ -1228,7 +1224,7 @@ EOT
       end
 
       ##
-      # Passes if +actual+ is false.
+      # Passes if `actual` is false.
       #
       # @example
       #   assert_false(false)  # -> pass
@@ -1244,8 +1240,8 @@ EOT
       end
 
       ##
-      # Passes if expression "+expected+ +operator+
-      # +actual+" is true.
+      # Passes if expression "`expected` `operator`
+      # `actual`" is true.
       #
       # @example
       #   assert_compare(1, "<", 10)  # -> pass
@@ -1300,7 +1296,7 @@ EOT
 
       ##
       # Passes if an exception is raised in block and its
-      # message is +expected+.
+      # message is `expected`.
       #
       # @example
       #   assert_raise_message("exception") {raise "exception"}  # -> pass
@@ -1340,7 +1336,7 @@ EOT
       end
 
       ##
-      # Passes if +object+.const_defined?(+constant_name+)
+      # Passes if `object`.const_defined?(`constant_name`)
       #
       # @example
       #   assert_const_defined(Test, :Unit)          # -> pass
@@ -1357,7 +1353,7 @@ EOT
       end
 
       ##
-      # Passes if !+object+.const_defined?(+constant_name+)
+      # Passes if !`object`.const_defined?(`constant_name`)
       #
       # @example
       #   assert_not_const_defined(Object, :Nonexistent) # -> pass
@@ -1374,7 +1370,7 @@ EOT
       end
 
       ##
-      # Passes if +object+.+predicate+ is _true_.
+      # Passes if `object`.`predicate` is _true_.
       #
       # @example
       #   assert_predicate([], :empty?)  # -> pass
@@ -1396,7 +1392,7 @@ EOT
       end
 
       ##
-      # Passes if +object+.+predicate+ is not _true_.
+      # Passes if `object`.`predicate` is not _true_.
       #
       # @example
       #   assert_not_predicate([1], :empty?) # -> pass
@@ -1423,8 +1419,8 @@ EOT
       alias_method :refute_predicate, :assert_not_predicate
 
       ##
-      # Passes if +object+#+alias_name+ is an alias method of
-      # +object+#+original_name+.
+      # Passes if `object`#`alias_name` is an alias method of
+      # `object`#`original_name`.
       #
       # @example
       #   assert_alias_method([], :length, :size)  # -> pass
@@ -1471,7 +1467,7 @@ EOT
       end
 
       ##
-      # Passes if +path+ exists.
+      # Passes if `path` exists.
       #
       # @example
       #   assert_path_exist("/tmp")          # -> pass
@@ -1489,7 +1485,7 @@ EOT
       end
 
       ##
-      # Passes if +path+ doesn't exist.
+      # Passes if `path` doesn't exist.
       #
       # @example
       #   assert_path_not_exist("/nonexistent")  # -> pass
@@ -1507,7 +1503,7 @@ EOT
       end
 
       ##
-      # Passes if +collection+ includes +object+.
+      # Passes if `collection` includes `object`.
       #
       # @example
       #   assert_include([1, 10], 1)            # -> pass
@@ -1534,7 +1530,7 @@ EOT
       alias_method :assert_includes, :assert_include
 
       ##
-      # Passes if +collection+ doesn't include +object+.
+      # Passes if `collection` doesn't include `object`.
       #
       # @example
       #   assert_not_include([1, 10], 5)            # -> pass
@@ -1566,7 +1562,7 @@ EOT
       alias_method :refute_includes, :assert_not_include
 
       ##
-      # Passes if +object+ is empty.
+      # Passes if `object` is empty.
       #
       # @example
       #   assert_empty("")                       # -> pass
@@ -1589,7 +1585,7 @@ EOT
       end
 
       ##
-      # Passes if +object+ is not empty.
+      # Passes if `object` is not empty.
       #
       # @example
       #   assert_not_empty(" ")                      # -> pass
@@ -1617,11 +1613,12 @@ EOT
       alias_method :refute_empty, :assert_not_empty
 
       ##
-      # Builds a failure message.  +head+ is added before the +template+ and
-      # +arguments+ replaces the '?'s positionally in the template.
-      def build_message(head, template=nil, *arguments)
+      # Builds a failure message.  `user_message` is added before the
+      # `template` and `arguments` replaces the '?'s positionally in
+      # the template.
+      def build_message(user_message, template=nil, *arguments)
         template &&= template.chomp
-        return AssertionMessage.new(head, template, arguments)
+        return AssertionMessage.new(user_message, template, arguments)
       end
 
       private
@@ -1688,12 +1685,11 @@ EOT
         end
       end
 
-      def _set_failed_information(failure, expected, actual, user_message)
+      def _set_failed_information(failure, expected, actual)
         failure.expected = expected
         failure.actual = actual
         failure.inspected_expected = AssertionMessage.convert(expected)
         failure.inspected_actual = AssertionMessage.convert(actual)
-        failure.user_message = user_message
       end
 
       class AssertionMessage
@@ -2071,8 +2067,8 @@ EOT
 
         include Util::BacktraceFilter
 
-        def initialize(head, template_string, parameters)
-          @head = head
+        def initialize(user_message, template_string, parameters)
+          @user_message = user_message
           @template_string = template_string
           @parameters = parameters
         end
@@ -2085,24 +2081,28 @@ EOT
           @template ||= Template.create(@template_string)
         end
 
-        def add_period(string)
-          (string =~ /\.\Z/ ? string : string + '.')
+        def user_message
+          return nil unless @user_message
+          message = @user_message
+          message = message.call if message.respond_to?(:call)
+          message.to_s
         end
 
         def to_s
           message_parts = []
-          if (@head)
-            head = @head
-            head = head.call if head.respond_to?(:call)
-            head = head.to_s
-            unless(head.empty?)
-              message_parts << add_period(head)
-            end
+          head = user_message
+          if head and not head.empty?
+            message_parts << add_period(head)
           end
           tail = template.result(@parameters.collect{|e| convert(e)})
           message_parts << tail unless(tail.empty?)
           message_parts.join("\n")
         end
+
+        private
+        def add_period(string)
+          (string =~ /\.\Z/ ? string : string + '.')
+        end
       end
 
       class AssertExceptionHelper
@@ -2114,7 +2114,14 @@ EOT
 
           def inspect
             if default_inspect?
-              "#{@exception.class.inspect}(<#{@exception.message}>)"
+              inspected = "#{@exception.class.inspect}(<#{@exception.message}>)"
+              unless (@exception.backtrace || []).empty?
+                inspected += "\n"
+                @exception.backtrace.each do |trace|
+                  inspected << "#{trace}\n"
+                end
+              end
+              inspected
             else
               @exception.inspect
             end
