@@ -32,6 +32,7 @@ module Test
           return_value = yield
           failed = false
         rescue AssertionFailedError => error
+          return_value = error
           actual_message = error.message
         end
         @catch_assertions = false
@@ -68,7 +69,10 @@ module Test
                   "Incorrect expected message type in assert_nothing_failed")
           end
         else
-          if return_value_expected
+          case return_value_expected
+          when :dont_care
+            # do nothing
+          when true
             check(!return_value.nil?, "Should return a value")
           else
             check(return_value.nil?,
@@ -94,7 +98,7 @@ module Test
 
       def check_fail_exception(expected_message, options={}, &proc)
         normalizer = lambda do |actual_message|
-          actual_message.gsub(/(^[^:\n]+:\d+:.+\n?)+\z/, "")
+          actual_message.gsub(/^(?:<internal:core> )?[^:\n]+:\d+:.+\n/, "")
         end
         check_assertions(true,
                          options.merge(:expected_message => expected_message,
@@ -124,22 +128,30 @@ module Test
     class TestAssertions < TestCase
       include AssertionCheckable
 
-      def test_assert_block
-        check_nothing_fails {
-          assert_block {true}
-        }
-        check_nothing_fails {
-          assert_block("successful assert_block") {true}
-        }
-        check_nothing_fails {
-          assert_block("successful assert_block") {true}
-        }
-        check_fail("assert_block failed.") {
-          assert_block {false}
-        }
-        check_fail("failed assert_block") {
-          assert_block("failed assert_block") {false}
-        }
+      class TestAssertBlock < self
+        def test_pass_without_message
+          check_nothing_fails {
+            assert_block {true}
+          }
+        end
+
+        def test_pass_with_message
+          check_nothing_fails {
+            assert_block("successful assert_block") {true}
+          }
+        end
+
+        def test_failure_without_message
+          check_fail("assert_block failed.") {
+            assert_block {false}
+          }
+        end
+
+        def test_failure_with_message
+          check_fail("failed assert_block") {
+            assert_block("failed assert_block") {false}
+          }
+        end
       end
 
       class TestAssertEqual < self
@@ -190,6 +202,23 @@ EOM
              assert_equal("string1", "string2", "failed assert_equal")
             }
           end
+
+          def test_with_message_proc
+            message = <<-EOM.chomp
+failed assert_equal.
+<"string1"> expected but was
+<"string2">.
+
+diff:
+- string1
+?       ^
++ string2
+?       ^
+EOM
+           check_fail(message) do
+              assert_equal("string1", "string2", lambda {"failed assert_equal"})
+            end
+          end
         end
 
         class TestSystemMessage < self
@@ -260,21 +289,26 @@ EOM
           end
 
           def test_same_inspected_objects
-            now = Time.now
-            now_without_usec = Time.at(now.to_i)
+            same_inspected_class = Class.new do
+              def inspect
+                "inspected"
+              end
+            end
+            object1 = same_inspected_class.new
+            object2 = same_inspected_class.new
             message = <<-EOM.chomp
-<#{now.inspect}> expected but was
-<#{now.inspect}>.
+<inspected> expected but was
+<inspected>.
 EOM
             check_fail(message) do
-              assert_equal(now, now_without_usec)
+              assert_equal(object1, object2)
             end
           end
 
           def test_multi_lines_result
             message = <<-EOM.chomp
-<#{"a\nb".inspect}> expected but was
-<#{"x".inspect}>.
+<#{AssertionMessage.convert("a\nb")}> expected but was
+<#{AssertionMessage.convert("x")}>.
 
 diff:
 + x
@@ -288,8 +322,8 @@ EOM
 
           def test_large_string
             message = <<-EOM.chomp
-<#{("a\n" + "x" * 997).inspect}> expected but was
-<#{"x".inspect}>.
+<#{AssertionMessage.convert("a\n" + "x" * 997)}> expected but was
+<#{AssertionMessage.convert("x")}>.
 
 diff:
 + x
@@ -307,8 +341,8 @@ EOM
             end
 
             message = <<-EOM.chomp
-<#{("a\n" + "x" * 998).inspect}> expected but was
-<#{"x".inspect}>.
+<#{AssertionMessage.convert("a\n" + "x" * 998)}> expected but was
+<#{AssertionMessage.convert("x")}>.
 EOM
             check_fail(message) do
               assert_equal("a\n" + "x" * 998, "x")
@@ -321,8 +355,8 @@ EOM
             ENV[key] = "100"
             begin
               message = <<-EOM.chomp
-<#{("a\n" + "x" * 97).inspect}> expected but was
-<#{"x".inspect}>.
+<#{AssertionMessage.convert("a\n" + "x" * 97)}> expected but was
+<#{AssertionMessage.convert("x")}>.
 
 diff:
 + x
@@ -340,8 +374,8 @@ EOM
               end
 
               message = <<-EOM.chomp
-<#{("a\n" + "x" * 98).inspect}> expected but was
-<#{"x".inspect}>.
+<#{AssertionMessage.convert("a\n" + "x" * 98)}> expected but was
+<#{AssertionMessage.convert("x")}>.
 EOM
               check_fail(message) do
                 assert_equal("a\n" + "x" * 98, "x")
@@ -467,7 +501,7 @@ EOM
       end
 
       def test_assert_raise_fail
-        check_fail("<RuntimeError> exception expected but none was thrown.") do
+        check_fail("<RuntimeError> exception was expected but none was thrown.") do
           assert_raise(RuntimeError) do
             1 + 1
           end
@@ -476,7 +510,8 @@ EOM
         message = <<-EOM.chomp
 failed assert_raise.
 <ArgumentError> exception expected but was
-<RuntimeError(<Error>)>.
+<RuntimeError(<Error>)
+>.
 EOM
         check_fail_exception(message) do
           assert_raise(ArgumentError, "failed assert_raise") do
@@ -485,8 +520,7 @@ EOM
         end
 
         message = <<-EOM
-Should expect a class of exception, Object.
-<false> is not true.
+<Object> must be a subclass of Exception, an object of Exception subclasses or a Module.
 EOM
         check_fail(message.chomp) do
           assert_nothing_raised(Object) do
@@ -529,7 +563,7 @@ EOM
         end
 
         check_fail("<[ArgumentError, TypeError, Math, Comparable]> exception " +
-                    "expected but none was thrown.") do
+                    "was expected but none was thrown.") do
           assert_raise(*rescues) do
             1 + 1
           end
@@ -538,7 +572,8 @@ EOM
         message = <<-EOM.chomp
 failed assert_raise.
 <[ArgumentError, TypeError]> exception expected but was
-<RuntimeError(<Error>)>.
+<RuntimeError(<Error>)
+>.
 EOM
         check_fail_exception(message) do
           assert_raise(ArgumentError, TypeError, "failed assert_raise") do
@@ -563,13 +598,8 @@ EOM
 
         message = <<-EOM.chomp
 <RuntimeError(<XXX>)> exception expected but was
-<RuntimeError(<Error>)>.
-
-diff:
-- RuntimeError(<XXX>)
-?               ^^^
-+ RuntimeError(<Error>)
-?               ^^^^^
+<RuntimeError(<Error>)
+>.
 EOM
         check_fail_exception(message) do
           return_value = assert_raise(RuntimeError.new("XXX")) do
@@ -580,7 +610,8 @@ EOM
         different_error_class = Class.new(StandardError)
         message = <<-EOM.chomp
 <#{different_error_class.inspect}(<Error>)> exception expected but was
-<RuntimeError(<Error>)>.
+<RuntimeError(<Error>)
+>.
 EOM
         check_fail_exception(message) do
           assert_raise(different_error_class.new("Error")) do
@@ -594,7 +625,8 @@ EOM
         end
         message = <<-EOM.chomp
 <DifferentError: "Error"> exception expected but was
-<RuntimeError(<Error>)>.
+<RuntimeError(<Error>)
+>.
 EOM
         check_fail_exception(message) do
           assert_raise(different_error) do
@@ -611,6 +643,21 @@ EOM
         end
       end
 
+      def test_assert_raise_jruby
+        jruby_only_test
+
+        exception = Java::JavaLang::StringIndexOutOfBoundsException
+
+        return_value = nil
+        check_nothing_fails(true) do
+          return_value = assert_raise(exception) do
+            Java::JavaLang::String.new("abc").char_at(4)
+          end
+        end
+        check(return_value.instance_of?(exception),
+              "Should have returned #{exception} but was #{return_value.class}")
+      end
+
       def test_assert_instance_of
         check_nothing_fails {
           assert_instance_of(String, "string")
@@ -621,21 +668,21 @@ EOM
         check_nothing_fails {
           assert_instance_of(String, "string", "successful assert_instance_of")
         }
-        check_fail(%Q{<"string"> expected to be instance_of?\n<Hash> but was\n<String>.}) {
+        check_fail(%Q{<"string"> was expected to be instance_of?\n<Hash> but was\n<String>.}) {
           assert_instance_of(Hash, "string")
         }
-        check_fail(%Q{failed assert_instance_of.\n<"string"> expected to be instance_of?\n<Hash> but was\n<String>.}) {
+        check_fail(%Q{failed assert_instance_of.\n<"string"> was expected to be instance_of?\n<Hash> but was\n<String>.}) {
           assert_instance_of(Hash, "string", "failed assert_instance_of")
         }
 
         check_nothing_fails do
-          assert_instance_of([Fixnum, NilClass], 100)
+          assert_instance_of([Class, NilClass], Array)
         end
-        check_fail(%Q{<"string"> expected to be instance_of?\n[<Fixnum>, <NilClass>] but was\n<String>.}) do
-          assert_instance_of([Fixnum, NilClass], "string")
+        check_fail(%Q{<"string"> was expected to be instance_of?\n[<Class>, <NilClass>] but was\n<String>.}) do
+          assert_instance_of([Class, NilClass], "string")
         end
-        check_fail(%Q{<100> expected to be instance_of?\n[<Numeric>, <NilClass>] but was\n<Fixnum>.}) do
-          assert_instance_of([Numeric, NilClass], 100)
+        check_fail(%Q{<Array> was expected to be instance_of?\n[<Module>, <NilClass>] but was\n<Class>.}) do
+          assert_instance_of([Module, NilClass], Array)
         end
       end
 
@@ -646,20 +693,20 @@ EOM
         check_nothing_fails {
           assert_not_instance_of(NilClass, "string", "successful assert_instance_of")
         }
-        check_fail(%Q{<"string"> expected to not be instance_of?\n<String> but was.}) {
+        check_fail(%Q{<"string"> was expected to not be instance_of?\n<String> but was.}) {
           assert_not_instance_of(String, "string")
         }
-        check_fail(%Q{failed assert.\n<"string"> expected to not be instance_of?\n<String> but was.}) {
+        check_fail(%Q{failed assert.\n<"string"> was expected to not be instance_of?\n<String> but was.}) {
           assert_not_instance_of(String, "string", "failed assert")
         }
 
         check_nothing_fails do
-          assert_not_instance_of([Numeric, NilClass], 100)
+          assert_not_instance_of([Module, NilClass], Array)
         end
-        check_fail(%Q{<100> expected to not be instance_of?\n[<Fixnum>, <NilClass>] but was.}) do
-          assert_not_instance_of([Fixnum, NilClass], 100)
+        check_fail(%Q{<Array> was expected to not be instance_of?\n[<Class>, <NilClass>] but was.}) do
+          assert_not_instance_of([Class, NilClass], Array)
         end
-        check_fail(%Q{<"str"> expected to not be instance_of?\n[<Numeric>, <String>] but was.}) do
+        check_fail(%Q{<"str"> was expected to not be instance_of?\n[<Numeric>, <String>] but was.}) do
           assert_not_instance_of([Numeric, String], 'str')
         end
       end
@@ -674,10 +721,10 @@ EOM
         check_nothing_fails {
           assert_nil(nil, "successful assert_nil")
         }
-        check_fail(%Q{<"string"> expected to be nil.}) {
+        check_fail(%Q{<"string"> was expected to be nil.}) {
           assert_nil("string")
         }
-        check_fail(%Q{failed assert_nil.\n<"string"> expected to be nil.}) {
+        check_fail(%Q{failed assert_nil.\n<"string"> was expected to be nil.}) {
           assert_nil("string", "failed assert_nil")
         }
       end
@@ -685,8 +732,8 @@ EOM
       def test_assert_not_nil
         check_nothing_fails{assert_not_nil(false)}
         check_nothing_fails{assert_not_nil(false, "message")}
-        check_fail("<nil> expected to not be nil."){assert_not_nil(nil)}
-        check_fail("message.\n<nil> expected to not be nil.") {assert_not_nil(nil, "message")}
+        check_fail("<nil> was expected to not be nil."){assert_not_nil(nil)}
+        check_fail("message.\n<nil> was expected to not be nil.") {assert_not_nil(nil, "message")}
       end
 
       def test_assert_kind_of
@@ -702,18 +749,18 @@ EOM
         check_nothing_fails {
           assert_kind_of(Comparable, 1)
         }
-        check_fail(%Q{<"string"> expected to be kind_of?\n<Class> but was\n<String>.}) {
+        check_fail(%Q{<"string"> was expected to be kind_of?\n<Class> but was\n<String>.}) {
           assert_kind_of(Class, "string")
         }
-        check_fail(%Q{failed assert_kind_of.\n<"string"> expected to be kind_of?\n<Class> but was\n<String>.}) {
+        check_fail(%Q{failed assert_kind_of.\n<"string"> was expected to be kind_of?\n<Class> but was\n<String>.}) {
           assert_kind_of(Class, "string", "failed assert_kind_of")
         }
 
         check_nothing_fails do
-          assert_kind_of([Fixnum, NilClass], 100)
+          assert_kind_of([Class, NilClass], Array)
         end
-        check_fail(%Q{<"string"> expected to be kind_of?\n[<Fixnum>, <NilClass>] but was\n<String>.}) do
-          assert_kind_of([Fixnum, NilClass], "string")
+        check_fail(%Q{<"string"> was expected to be kind_of?\n[<Class>, <NilClass>] but was\n<String>.}) do
+          assert_kind_of([Class, NilClass], "string")
         end
       end
 
@@ -727,18 +774,18 @@ EOM
         check_nothing_fails {
           assert_not_kind_of(Integer, 1.1)
         }
-        check_fail(%Q{<1> expected to not be kind_of?\n<Integer> but was.}) {
+        check_fail(%Q{<1> was expected to not be kind_of?\n<Integer> but was.}) {
           assert_not_kind_of(Integer, 1)
         }
-        check_fail(%Q{failed assert_not_kind_of.\n<"string"> expected to not be kind_of?\n<String> but was.}) {
+        check_fail(%Q{failed assert_not_kind_of.\n<"string"> was expected to not be kind_of?\n<String> but was.}) {
           assert_not_kind_of(String, "string", "failed assert_not_kind_of")
         }
 
         check_nothing_fails do
           assert_not_kind_of([String, NilClass], 100)
         end
-        check_fail(%Q{<100> expected to not be kind_of?\n[<Fixnum>, <NilClass>] but was.}) do
-          assert_not_kind_of([Fixnum, NilClass], 100)
+        check_fail(%Q{<Array> was expected to not be kind_of?\n[<Class>, <NilClass>] but was.}) do
+          assert_not_kind_of([Class, NilClass], Array)
         end
       end
 
@@ -755,13 +802,13 @@ EOM
         check_nothing_fails {
           assert_match(/strin./, "string", "successful assert_match")
         }
-        check_fail(%Q{<"string"> expected to be =~\n</slin./>.}) {
+        check_fail(%Q{</slin./> was expected to be =~\n<"string">.}) {
           assert_match(/slin./, "string")
         }
-        check_fail(%Q{<"string"> expected to be =~\n</strin\\./>.}) {
+        check_fail(%Q{</strin\\./> was expected to be =~\n<"string">.}) {
           assert_match("strin.", "string")
         }
-        check_fail(%Q{failed assert_match.\n<"string"> expected to be =~\n</slin./>.}) {
+        check_fail(%Q{failed assert_match.\n</slin./> was expected to be =~\n<"string">.}) {
           assert_match(/slin./, "string", "failed assert_match")
         }
       end
@@ -777,32 +824,32 @@ EOM
         check_nothing_fails {
           assert_same(thing, thing, "successful assert_same")
         }
-        thing2 = "thing"
-        check_fail(%Q{<"thing">\nwith id <#{thing.__id__}> expected to be equal? to\n<"thing">\nwith id <#{thing2.__id__}>.}) {
+        thing2 = thing.dup
+        check_fail(%Q{<"thing">\nwith id <#{thing.__id__}> was expected to be equal? to\n<"thing">\nwith id <#{thing2.__id__}>.}) {
           assert_same(thing, thing2)
         }
-        check_fail(%Q{failed assert_same.\n<"thing">\nwith id <#{thing.__id__}> expected to be equal? to\n<"thing">\nwith id <#{thing2.__id__}>.}) {
+        check_fail(%Q{failed assert_same.\n<"thing">\nwith id <#{thing.__id__}> was expected to be equal? to\n<"thing">\nwith id <#{thing2.__id__}>.}) {
           assert_same(thing, thing2, "failed assert_same")
         }
       end
 
       def test_assert_nothing_raised
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised("successful assert_nothing_raised") {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           assert_nothing_raised("successful assert_nothing_raised") {
             1 + 1
           }
         }
-        check_nothing_fails {
+        check_nothing_fails(:dont_care) {
           begin
             assert_nothing_raised(RuntimeError, StandardError, Comparable, "successful assert_nothing_raised") {
               raise ZeroDivisionError.new("ArgumentError")
@@ -810,7 +857,10 @@ EOM
           rescue ZeroDivisionError
           end
         }
-        check_fail("Should expect a class of exception, Object.\n<false> is not true.") {
+        expected_message =
+          "<Object> must be a subclass of Exception, " +
+          "an object of Exception subclasses or a Module."
+        check_fail(expected_message) {
           assert_nothing_raised(Object) {
             1 + 1
           }
@@ -818,6 +868,7 @@ EOM
         expected_message = <<-EOM.chomp
 Exception raised:
 RuntimeError(<Error>)
+
 EOM
         check_fail_exception(expected_message) {
           assert_nothing_raised {
@@ -828,6 +879,7 @@ EOM
 failed assert_nothing_raised.
 Exception raised:
 RuntimeError(<Error>)
+
 EOM
         check_fail_exception(expected_message) {
           assert_nothing_raised("failed assert_nothing_raised") {
@@ -837,6 +889,7 @@ EOM
         expected_message = <<-EOM.chomp
 Exception raised:
 RuntimeError(<Error>)
+
 EOM
         check_fail_exception(expected_message) {
           assert_nothing_raised(StandardError, RuntimeError) {
@@ -861,17 +914,17 @@ EOM
 
       def test_assert_not_same
         thing = "thing"
-        thing2 = "thing"
+        thing2 = thing.dup
         check_nothing_fails {
           assert_not_same(thing, thing2)
         }
         check_nothing_fails {
           assert_not_same(thing, thing2, "message")
         }
-        check_fail(%Q{<"thing">\nwith id <#{thing.__id__}> expected to not be equal? to\n<"thing">\nwith id <#{thing.__id__}>.}) {
+        check_fail(%Q{<"thing">\nwith id <#{thing.__id__}> was expected to not be equal? to\n<"thing">\nwith id <#{thing.__id__}>.}) {
           assert_not_same(thing, thing)
         }
-        check_fail(%Q{message.\n<"thing">\nwith id <#{thing.__id__}> expected to not be equal? to\n<"thing">\nwith id <#{thing.__id__}>.}) {
+        check_fail(%Q{message.\n<"thing">\nwith id <#{thing.__id__}> was expected to not be equal? to\n<"thing">\nwith id <#{thing.__id__}>.}) {
           assert_not_same(thing, thing, "message")
         }
       end
@@ -883,10 +936,10 @@ EOM
         check_nothing_fails {
           assert_not_equal("string1", "string2", "message")
         }
-        check_fail(%Q{<"string"> expected to be != to\n<"string">.}) {
+        check_fail(%Q{<"string"> was expected to be != to\n<"string">.}) {
           assert_not_equal("string", "string")
         }
-        check_fail(%Q{message.\n<"string"> expected to be != to\n<"string">.}) {
+        check_fail(%Q{message.\n<"string"> was expected to be != to\n<"string">.}) {
           assert_not_equal("string", "string", "message")
         }
       end
@@ -903,26 +956,23 @@ EOM
         end
       end
 
-      def test_assert_not_match_fail_not_regexp
-        check_fail("<REGEXP> in assert_not_match(<REGEXP>, ...) " +
-                    "should be a Regexp.\n" +
-                    "<\"asdf\"> expected to be instance_of?\n" +
-                    "<Regexp> but was\n" +
-                    "<String>.") do
-          assert_not_match("asdf", "asdf")
-        end
-      end
-
       def test_assert_not_match_fail_match
-        check_fail("</string/> expected to not match\n" +
+        check_fail("</string/> was expected to not match\n" +
                     "<\"string\">.") do
           assert_not_match(/string/, "string")
         end
       end
 
+      def test_assert_not_match_fail_match_string
+        check_fail("</asdf/> was expected to not match\n" +
+                    "<\"asdf\">.") do
+          assert_not_match("asdf", "asdf")
+        end
+      end
+
       def test_assert_not_match_fail_match_with_message
         check_fail("message.\n" +
-                    "</string/> expected to not match\n" +
+                    "</string/> was expected to not match\n" +
                     "<\"string\">.") do
           assert_not_match(/string/, "string", "message")
         end
@@ -931,13 +981,13 @@ EOM
       def test_assert_no_match
         check_nothing_fails{assert_no_match(/sling/, "string")}
         check_nothing_fails{assert_no_match(/sling/, "string", "message")}
-        check_fail(%Q{The first argument to assert_no_match should be a Regexp.\n<"asdf"> expected to be instance_of?\n<Regexp> but was\n<String>.}) do
+        check_fail(%Q{The first argument to assert_no_match should be a Regexp.\n<"asdf"> was expected to be instance_of?\n<Regexp> but was\n<String>.}) do
           assert_no_match("asdf", "asdf")
         end
-        check_fail(%Q{</string/> expected to not match\n<"string">.}) do
+        check_fail(%Q{</string/> was expected to not match\n<"string">.}) do
           assert_no_match(/string/, "string")
         end
-        check_fail(%Q{message.\n</string/> expected to not match\n<"string">.}) do
+        check_fail(%Q{message.\n</string/> was expected to not match\n<"string">.}) do
           assert_no_match(/string/, "string", "message")
         end
       end
@@ -951,7 +1001,7 @@ EOM
 
         tag = :thing2
         check_fail("message.\n" +
-                    "<:thing> expected to be thrown but\n" +
+                    "<:thing> was expected to be thrown but\n" +
                     "<#{inspect_tag(tag)}> was thrown.") do
           assert_throw(:thing, "message") do
             throw :thing2
@@ -989,7 +1039,7 @@ EOM
         check_fail(%Q{<0.15>\ngiven as the operator for #assert_operator must be a Symbol or #respond_to?(:to_str).}) do
           assert_operator("thing", 0.15, "thing")
         end
-        check_fail(%Q{message.\n<"thing1"> expected to be\n==\n<"thing2">.}) {
+        check_fail(%Q{message.\n<"thing1"> was expected to be\n==\n<"thing2">.}) {
           assert_operator("thing1", :==, "thing2", "message")
         }
       end
@@ -1001,7 +1051,7 @@ EOM
         check_fail(%Q{<42>\ngiven as the operator for #assert_not_operator must be a Symbol or #respond_to?(:to_str).}) do
           assert_not_operator("thing", 42, "message")
         end
-        check_fail(%Q{message.\n<0> expected to not be\n==\n<0.0>.}) {
+        check_fail(%Q{message.\n<0> was expected to not be\n==\n<0.0>.}) {
           assert_not_operator(0, :==, 0.0, "message")
         }
       end
@@ -1066,7 +1116,7 @@ EOM
         inspected_object = AssertionMessage.convert(object)
         expected_message = <<-EOM
 message.
-<#{inspected_object}> expected to respond to
+<#{inspected_object}> was expected to respond to
 <return_argument(*[false, "bogus"])> with a true value but was
 <false>.
 EOM
@@ -1123,9 +1173,10 @@ EOM
           assert_true(1)
         end
 
-        check_fail("message.\n<true> expected but was\n<nil>") do
+        exception = check_fail("message.\n<true> expected but was\n<nil>") do
           assert_true(nil, "message")
         end
+        assert_equal("message", exception.user_message)
       end
 
       def test_assert_false
@@ -1165,7 +1216,7 @@ EOM
 
         expected_message = <<-EOM
 <15> < <10> should be true
-<15> expected less than
+<15> was expected to be less than
 <10>.
 EOM
         check_fail(expected_message.chomp) do
@@ -1174,7 +1225,7 @@ EOM
 
         expected_message = <<-EOM
 <15> <= <10> should be true
-<15> expected less than or equal to
+<15> was expected to be less than or equal to
 <10>.
 EOM
         check_fail(expected_message.chomp) do
@@ -1183,7 +1234,7 @@ EOM
 
         expected_message = <<-EOM
 <10> > <15> should be true
-<10> expected greater than
+<10> was expected to be greater than
 <15>.
 EOM
         check_fail(expected_message.chomp) do
@@ -1192,7 +1243,7 @@ EOM
 
         expected_message = <<-EOM
 <10> >= <15> should be true
-<10> expected greater than or equal to
+<10> was expected to be greater than or equal to
 <15>.
 EOM
         check_fail(expected_message.chomp) do
@@ -1243,7 +1294,7 @@ EOM
         end
 
         expected_message = <<-EOM
-<"Expected message"> exception message expected but none was thrown.
+<"Expected message"> exception message was expected but none was thrown.
 EOM
         check_fail(expected_message.chomp) do
           assert_raise_message("Expected message") do
@@ -1260,7 +1311,8 @@ EOM
 
         expected_message = <<-EOM.chomp
 <SystemCallError> family exception expected but was
-<RuntimeError(<XXX>)>.
+<RuntimeError(<XXX>)
+>.
 EOM
         check_fail_exception(expected_message) do
           assert_raise_kind_of(SystemCallError) do
@@ -1369,7 +1421,7 @@ EOM
         end
 
         nonexistent_file = __FILE__ + ".nonexistent"
-        check_fail("<#{nonexistent_file.inspect}> expected to exist") do
+        check_fail("<#{nonexistent_file.inspect}> was expected to exist") do
           assert_path_exist(nonexistent_file)
         end
       end
@@ -1380,7 +1432,7 @@ EOM
           assert_path_not_exist(nonexistent_file)
         end
 
-        check_fail("<#{__FILE__.inspect}> expected to not exist") do
+        check_fail("<#{__FILE__.inspect}> was expected to not exist") do
           assert_path_not_exist(__FILE__)
         end
       end
@@ -1476,15 +1528,18 @@ EOM
       class TestBlock < self
         def test_with_message
           if defined?(PowerAssert)
-            system_message = <<-MESSAGE
-              1 == 2
+            system_message = <<-MESSAGE.chomp
+              1.to_s == "2"
+                |    |
+                |    false
+                "1"
 MESSAGE
           else
             system_message = "<false> is not true."
           end
           check_fail("user message.\n#{system_message}") do
             assert("user message") do
-              1 == 2
+              1.to_s == "2"
             end
           end
         end
@@ -1590,7 +1645,7 @@ MESSAGE
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<0.5> -/+ <0.05> expected to include\n" +
+                    "<0.5> -/+ <0.05> was expected to include\n" +
                     "<0.4>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1612,13 +1667,13 @@ MESSAGE
 
       def test_fail_because_negaitve_delta
         check_fail("The delta should not be negative.\n" +
-                    "<-0.1> expected to be\n>=\n<0.0>.") do
+                    "<-0.1> was expected to be\n>=\n<0.0>.") do
           assert_in_delta(0.5, 0.4, -0.1, "message")
         end
       end
 
       def test_fail_without_delta
-        check_fail("<1.402> -/+ <0.001> expected to include\n" +
+        check_fail("<1.402> -/+ <0.001> was expected to include\n" +
                     "<1.404>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1670,7 +1725,7 @@ MESSAGE
       end
 
       def test_fail
-        check_fail("<1.4> -/+ <0.11> expected to not include\n" +
+        check_fail("<1.4> -/+ <0.11> was expected to not include\n" +
                     "<1.5>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1684,7 +1739,7 @@ MESSAGE
       end
 
       def test_fail_without_delta
-        check_fail("<1.402> -/+ <0.001> expected to not include\n" +
+        check_fail("<1.402> -/+ <0.001> was expected to not include\n" +
                     "<1.4021>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1699,7 +1754,7 @@ MESSAGE
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<0.5> -/+ <0.11> expected to not include\n" +
+                    "<0.5> -/+ <0.11> was expected to not include\n" +
                     "<0.4>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1725,7 +1780,7 @@ MESSAGE
 
       def test_fail_because_negaitve_delta
         check_fail("The delta should not be negative.\n" +
-                    "<-0.11> expected to be\n>=\n<0.0>.") do
+                    "<-0.11> was expected to be\n>=\n<0.0>.") do
           assert_not_in_delta(0.5, 0.4, -0.11, "message")
         end
       end
@@ -1783,7 +1838,7 @@ MESSAGE
       def test_fail_with_message
         check_fail("message.\n" +
                     "<10000> -/+ (<10000> * <0.1>)[1000.0] " +
-                    "expected to include\n" +
+                    "was expected to include\n" +
                     "<8999>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1809,14 +1864,14 @@ MESSAGE
 
       def test_fail_because_negaitve_epsilon
         check_fail("The epsilon should not be negative.\n" +
-                    "<-0.1> expected to be\n>=\n<0.0>.") do
+                    "<-0.1> was expected to be\n>=\n<0.0>.") do
           assert_in_epsilon(10000, 9000, -0.1, "message")
         end
       end
 
       def test_fail_without_epsilon
         check_fail("<10000> -/+ (<10000> * <0.001>)[10.0] " +
-                    "expected to include\n" +
+                    "was expected to include\n" +
                     "<10011>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1869,7 +1924,7 @@ MESSAGE
 
       def test_fail
         check_fail("<10000> -/+ (<10000> * <0.1>)[1000.0] " +
-                    "expected to not include\n" +
+                    "was expected to not include\n" +
                     "<9000>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1884,7 +1939,7 @@ MESSAGE
 
       def test_fail_without_epsilon
         check_fail("<10000> -/+ (<10000> * <0.001>)[10.0] " +
-                    "expected to not include\n" +
+                    "was expected to not include\n" +
                     "<9990>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1900,7 +1955,7 @@ MESSAGE
       def test_fail_with_message
         check_fail("message.\n" +
                     "<10000> -/+ (<10000> * <0.1>)[1000.0] " +
-                    "expected to not include\n" +
+                    "was expected to not include\n" +
                     "<9000>.\n" +
                     "\n" +
                     "Relation:\n" +
@@ -1926,7 +1981,7 @@ MESSAGE
 
       def test_fail_because_negaitve_epsilon
         check_fail("The epsilon should not be negative.\n" +
-                    "<-0.1> expected to be\n>=\n<0.0>.") do
+                    "<-0.1> was expected to be\n>=\n<0.0>.") do
           assert_not_in_epsilon(10000, 9000, -0.1, "message")
         end
       end
@@ -1948,7 +2003,7 @@ MESSAGE
       end
 
       def test_fail
-        check_fail("<[1, 2, 3]> expected to include\n" +
+        check_fail("<[1, 2, 3]> was expected to include\n" +
                     "<4>.") do
           assert_include([1, 2, 3], 4)
         end
@@ -1956,7 +2011,7 @@ MESSAGE
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<[1, 2, 3]> expected to include\n" +
+                    "<[1, 2, 3]> was expected to include\n" +
                     "<4>.") do
           assert_include([1, 2, 3], 4, "message")
         end
@@ -1989,7 +2044,7 @@ MESSAGE
       end
 
       def test_fail
-        check_fail("<[1, 2, 3]> expected to not include\n" +
+        check_fail("<[1, 2, 3]> was expected to not include\n" +
                     "<2>.") do
           assert_not_include([1, 2, 3], 2)
         end
@@ -1997,7 +2052,7 @@ MESSAGE
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<[1, 2, 3]> expected to not include\n" +
+                    "<[1, 2, 3]> was expected to not include\n" +
                     "<2>.") do
           assert_not_include([1, 2, 3], 2, "message")
         end
@@ -2030,14 +2085,14 @@ MESSAGE
       end
 
       def test_fail
-        check_fail("<[1]> expected to be empty.") do
+        check_fail("<[1]> was expected to be empty.") do
           assert_empty([1])
         end
       end
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<[1]> expected to be empty.") do
+                    "<[1]> was expected to be empty.") do
           assert_empty([1], "message")
         end
       end
@@ -2069,14 +2124,14 @@ MESSAGE
       end
 
       def test_fail
-        check_fail("<[]> expected to not be empty.") do
+        check_fail("<[]> was expected to not be empty.") do
           assert_not_empty([])
         end
       end
 
       def test_fail_with_message
         check_fail("message.\n" +
-                    "<[]> expected to not be empty.") do
+                    "<[]> was expected to not be empty.") do
           assert_not_empty([], "message")
         end
       end
@@ -2104,7 +2159,7 @@ MESSAGE
       def test_fail
         expected_message = <<-EOM
 message.
-<[1, 2]> expected to respond to
+<[1, 2]> was expected to respond to
 <member?(*[2])> with not a true value but was
 <true>.
 EOM
